==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/desktopvirtualization/kotlin/inputs/GetScalingPlanPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.desktopvirtualization.kotlin.inputs

import com.pulumi.azurenative.desktopvirtualization.inputs.GetScalingPlanPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property scalingPlanName The name of the scaling plan.
 */
public data class GetScalingPlanPlainArgs(
    public val resourceGroupName: String,
    public val scalingPlanName: String,
) : ConvertibleToJava<com.pulumi.azurenative.desktopvirtualization.inputs.GetScalingPlanPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.desktopvirtualization.inputs.GetScalingPlanPlainArgs =
        com.pulumi.azurenative.desktopvirtualization.inputs.GetScalingPlanPlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .scalingPlanName(scalingPlanName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetScalingPlanPlainArgs].
 */
@PulumiTagMarker
public class GetScalingPlanPlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var scalingPlanName: String? = null

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("bxkctjhgqavlldrk")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the scaling plan.
     */
    @JvmName("qytdmmexccjfhlcg")
    public suspend fun scalingPlanName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.scalingPlanName = mapped
    }

    internal fun build(): GetScalingPlanPlainArgs = GetScalingPlanPlainArgs(
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        scalingPlanName = scalingPlanName ?: throw PulumiNullFieldException("scalingPlanName"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/desktopvirtualization/kotlin/inputs/GetScalingPlanPlainArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.desktopvirtualization.kotlin.inputs

import com.pulumi.azurenative.desktopvirtualization.inputs.GetScalingPlanPlainArgs.builder
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property scalingPlanName The name of the scaling plan.
 */
public data class GetScalingPlanPlainArgs(
    public val resourceGroupName: String,
    public val scalingPlanName: String,
) : ConvertibleToJava<com.pulumi.azurenative.desktopvirtualization.inputs.GetScalingPlanPlainArgs> {
    override fun toJava(): com.pulumi.azurenative.desktopvirtualization.inputs.GetScalingPlanPlainArgs =
        com.pulumi.azurenative.desktopvirtualization.inputs.GetScalingPlanPlainArgs.builder()
            .resourceGroupName(resourceGroupName.let({ args0 -> args0 }))
            .scalingPlanName(scalingPlanName.let({ args0 -> args0 })).build()
}

/**
 * Builder for [GetScalingPlanPlainArgs].
 */
@PulumiTagMarker
public class GetScalingPlanPlainArgsBuilder internal constructor() {
    private var resourceGroupName: String? = null

    private var scalingPlanName: String? = null

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("ndrmteybnvvfxlfo")
    public suspend fun resourceGroupName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.resourceGroupName = mapped
    }

    /**
     * @param value The name of the scaling plan.
     */
    @JvmName("pldqwiaqxqwiujur")
    public suspend fun scalingPlanName(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> args0 })
        this.scalingPlanName = mapped
    }

    internal fun build(): GetScalingPlanPlainArgs = GetScalingPlanPlainArgs(
        resourceGroupName = resourceGroupName ?: throw PulumiNullFieldException("resourceGroupName"),
        scalingPlanName = scalingPlanName ?: throw PulumiNullFieldException("scalingPlanName"),
    )
}
